@@ -4,6 +4,7 @@
 
 #include <config.h>
 #include <applet-widget.h>
+#include <libgnomeui/gnome-window-icon.h>
 #include "charpick.h"
 
 
@@ -461,7 +462,7 @@ about (AppletWidget *applet, gpointer data)
 
 
 static void
-help_cb (GtkWidget *w, gpointer data)
+help_cb (AppletWidget *applet, gpointer data)
 {
         GnomeHelpMenuEntry help_entry = { "charpick_applet",
                                           "index.html" };
@@ -526,7 +527,7 @@ main (int argc, char *argv[])
   /* initialize applet */
   applet_widget_init("charpick_applet", CHARPICK_VERSION, argc, argv,
 			      NULL, 0, NULL);
-
+  gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/charpick.png");
   /* create a new applet_widget*/
   applet = applet_widget_new("charpick_applet");
   curr_data.applet = applet; 
